@@ -31,6 +31,7 @@ from datetime import datetime
 import tensorflow as tf
 
 from dnnlab.errors.dnnlab_exceptions import ModelNotCompiledError
+from dnnlab.losses.ocr import OCRLoss
 
 os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"  # FATAL
 logging.getLogger("tensorflow").setLevel(logging.FATAL)
@@ -64,6 +65,7 @@ class NN():
         model: keras.model. Keras NN transforming inputs to outputs.
         alpha. Float between 0,1. Interpolation weight for combined losses.
     """
+
     def __init__(self, model, alpha=0.84):
         """ Inits nn with ckpt managers and loggers for tensorboard. alpha
         defaults to 0.84 as suggested by the authors."""
@@ -153,8 +155,7 @@ class NN():
         """Standard prediciton."""
         return self.model.predict(img)
 
-    def compile(self, loss="l2", optimizer="adam", lr=1e-4,
-                loss_scaling=False):
+    def compile(self, loss="l2", optimizer="adam", lr=1e-4, loss_scaling=False):
         """Defines the optimization part of the learning algorithm to our
         learning model. Choose between following loss functions:
             - l1 = mean absolute error (mae)
@@ -167,7 +168,7 @@ class NN():
             - TODO mssim_l2 = mssim + l2
 
         Args:
-            loss: String. Loss function to use.
+            loss: String or Loss Object. Loss function to use.
             optimizer: String. Optimizer. Defaults to "adam".
             lr: Float. Learning rate. Defaults to 1e4.
             loss_scaling: Boolean. Loss scaling for mixed presicion.
@@ -186,6 +187,8 @@ class NN():
             self.loss_objective = self._ssim_l1_loss
         elif self.loss == "ssim_l2":
             self.loss_objective = self._ssim_l2_loss
+        else:
+            self.loss_objective = loss
 
         if optimizer == "adadelta":
             self.optimizer = tf.keras.optimizers.Adadelta(lr)
@@ -445,21 +448,25 @@ class NN():
         mae = tf.keras.losses.MeanAbsoluteError()
         mse = tf.keras.losses.MeanSquaredError()
         ssim = self._ssim
+        ocr = OCRLoss(neighbourhood=9, background_weight=0.0)
         # mssim = self._mssim_loss
         print("Start evaluation...")
         mae_metric = tf.keras.metrics.Mean()
         mse_metric = tf.keras.metrics.Mean()
         ssim_metric = tf.keras.metrics.Mean()
+        ocr_metric = tf.keras.metrics.Mean()
         #mssim_metric = tf.keras.metrics.Mean()
         for images, labels in dataset:
             _, prediction = self.test_step(images, labels)
             mae_metric.update_state(mae(labels, prediction))
             mse_metric.update_state(mse(labels, prediction))
             ssim_metric.update_state(ssim(labels, prediction))
+            ocr_metric.update_state(ocr(labels, prediction))
 
         result = {
             "l1": float(mae_metric.result()),
             "l2": float(mse_metric.result()),
-            "ssim": float(ssim_metric.result())
+            "ssim": float(ssim_metric.result()),
+            "ocr": float(ocr_metric.result())
         }
         return result
